package com.muyu.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;

/**
 * 故障日志实体类
 *  * @className: FaultLog  ️✈️
 *  * @author: Yang 鹏  🦅
 *  * @date: 2024/9/23 21:06 ⏰
 *  * @Version: 1.0
 *  * @description: 故障日志实体类
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@Tag(name = "故障日志实体类",description = "故障日志实体类")
@TableName(value = "car_fault_log",autoResultMap = true)
public class FaultLog {

    /**
     * 故障日志Id
     */
    @TableId(value = "log_id",type = IdType.AUTO)
    @Schema(name = "故障日志Id")
    private long logId;
    /**
     * 故障码Id
     */
    @Schema(name = "故障码Id")
    private long faultcodeId;
    /**
     * 车辆Id
     */
    @Schema(name = "车辆Id")
    private long carInformationId;
    /**
     * 车辆VIN
     */
    @Schema(name = "车辆VIN")
    private String carVin;
    /**
     * 开始报警时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "开始报警时间",defaultValue = "2024-8-9 10:47:57",type = "Date")
    private Date startwarningTime;
    /**
     * 结束报警时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "结束报警时间",defaultValue = "2024-8-9 10:47:57",type = "Date")
    private Date endwarningTime;
    /**
     * 故障码
     */
    @Schema(name = "故障码")
    private String faultcodeNumber;
    /**
     * 车辆vin
     */
    @Schema(name = "车辆vin")
    private String carInformationVIN;

}
