package com.muyu.enterpise.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.domain.WarnRule;
import com.muyu.enterpise.service.IWarnRuleService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.List;

/**
 * 预警规则Controller
 * @author muyu
 * @date 2024-09-20
 */
@RestController
@RequestMapping("/rule")
@Tag(name = "查询预警规则模块",description = "查询预警规则模块")
public class WarnRuleController extends BaseController
{
    @Resource
    private IWarnRuleService warnRuleService;

    /**
     * 查询预警规则列表
     */
    @GetMapping("/list")
    public Result<TableDataInfo<WarnRule>> list(WarnRule warnRule)
    {
        startPage();
        List<WarnRule> list = warnRuleService.selectWarnRuleList(warnRule);
        return getDataTable(list);
    }

    /**
     * 导出预警规则列表
     */
    @PostMapping("/export")
    public void export(HttpServletResponse response, WarnRule warnRule)
    {
        List<WarnRule> list = warnRuleService.selectWarnRuleList(warnRule);
        ExcelUtil<WarnRule> util = new ExcelUtil<WarnRule>(WarnRule.class);
        util.exportExcel(response, list, "预警规则数据");
    }

    /**
     * 获取预警规则详细信息
     */
    @GetMapping(value = "/{id}")
    public Result<List<WarnRule>> getInfo(@PathVariable("id") Long id)
    {
        return success(warnRuleService.selectWarnRuleById(id));
    }

    /**
     * 新增预警规则
     */
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody WarnRule warnRule)
    {
        if (warnRuleService.checkIdUnique(warnRule)) {
            return error("新增 预警规则 '" + warnRule + "'失败，预警规则已存在");
        }
        warnRule.setCreateBy(SecurityUtils.getUsername());
        return toAjax(warnRuleService.save(warnRule));
    }

    /**
     * 修改预警规则
     */
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody WarnRule warnRule)
    {
        if (!warnRuleService.checkIdUnique(warnRule)) {
            return error("修改 预警规则 '" + warnRule + "'失败，预警规则不存在");
        }
        warnRule.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(warnRuleService.updateById(warnRule));
    }

    /**
     * 删除预警规则
     */
	@DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable("ids") Long[] ids)
    {
        warnRuleService.removeBatchByIds(Arrays.asList(ids));
        return success();
    }
}
